package com.llisoft.pay.config;

import java.io.IOException;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.annotation.Order;
import org.springframework.http.HttpStatus;
import org.springframework.web.filter.OncePerRequestFilter;

import com.llisoft.pay.common.CodeEnum;
import com.llisoft.pay.util.JsonUtil;
import com.llisoft.pay.vo.ResponseVo;

/**
 * 全局异常过滤器
 * 处理在filter中抛出异常时正常返回json
 * 使过滤器生效，必须注入到容器并设置顺序到最前
 * @author YangJie [2019年10月25日]
 */
@Configuration
@Order(Integer.MIN_VALUE + 1) // 指定顺序，需要在跨域过滤器之后，其他过滤器之前
public class ExceptionFilterConfig extends OncePerRequestFilter {
	
	private Logger logger = LoggerFactory.getLogger(ExceptionFilterConfig.class);

	@Override
	protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain filterChain)
			throws ServletException, IOException {
		try {
			filterChain.doFilter(request, response);
		} catch (Throwable exception) { // 抛异常情况
			if(!(exception instanceof IOException)) {
				logger.error("过滤器异常：{}", exception.getMessage());
			}
			response.setStatus(HttpStatus.OK.value()); // 状态码200
			response.setContentType("application/json; charset=utf-8");
			CodeEnum codeEnum = CodeEnum.C500;
			if (exception instanceof MtaException) {
				codeEnum = ((MtaException)exception).getCodeEnum();
			}
			try { // 返回json
				response.getWriter().write(JsonUtil.toJson(ResponseVo.build(codeEnum)));
			} catch (Exception e) {
				// e.printStackTrace();
			}
		}
	}

}
