package com.llisoft.pay.controller;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;

import com.llisoft.pay.service.ApiService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@Api(tags="支付宝回调")
@Controller
@RequestMapping("/callback/alipay")
public class CallbackAliPayController {
	
	private Logger logger = LoggerFactory.getLogger(CallbackAliPayController.class);

	@Autowired
	private ApiService apiService;
	
	
	@ApiOperation("异步通知")
	@PostMapping("/notify/{pid}")
	public ResponseEntity<String> notify(@PathVariable String pid, HttpServletRequest request) throws Exception {
		if(apiService.aliNotify(pid, this.getParamMap(request))) {
			return ResponseEntity.ok().build();
		}
		return ResponseEntity.badRequest().build();
	}
	
	
	/**
	 * 获取参数Map<String, String>
	 * @param request
	 * @return
	 */
	private Map<String, String> getParamMap(HttpServletRequest request){
		Map<String, String> returnMap = new HashMap<String, String>();
		Map<String, String[]> paramMap = request.getParameterMap();
		for (String key: paramMap.keySet()) {
			String[] values = paramMap.get(key);
			if (values!=null && values.length>0) {
				returnMap.put(key, values[0]);
			}
		}
		logger.debug("收到支付宝异步通知: {}", returnMap);
		return returnMap;
	}

}