package com.llisoft.pay.controller;

import javax.validation.Valid;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.llisoft.pay.service.OrderService;
import com.llisoft.pay.util.JsonUtil;
import com.llisoft.pay.vo.OrderAddRequestVo;
import com.llisoft.pay.vo.OrderPayRequestVo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@Api(tags="支付订单")
@RestController
@RequestMapping("/order")
@Deprecated // 接口升级 > ApiController
public class OrderController{
	
	private Logger logger = LoggerFactory.getLogger(OrderController.class);
	
	@Autowired
	private OrderService orderService;
	
	
	@ApiOperation(value="订单添加")
	@PostMapping("/add")
	public String add(@Valid @RequestBody OrderAddRequestVo vo) throws Exception{
		logger.debug("收到订单添加请求: {}", JsonUtil.toJson(vo));
		return orderService.add(vo.getAppKey(), vo.getMoney(), vo.getTitle());
	}
	
	@ApiOperation(value="订单支付")
	@PostMapping("/pay")
	public String pay(@Valid @RequestBody OrderPayRequestVo vo) throws Exception{
		logger.debug("收到订单支付请求: {}", JsonUtil.toJson(vo));
		return orderService.pay(vo.getOrderNum(), vo.getPayType(), vo.isMobile());
	}
	
	@ApiOperation(value="订单核对")
	@GetMapping("/check/{orderNum}")
	public boolean check(@PathVariable String orderNum) throws Exception{
		logger.debug("收到订单核对请求: {}", orderNum);
		return orderService.check(orderNum);
	}
	
}