package com.llisoft.pay.util;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import org.springframework.beans.BeanUtils;

/**
 * 实体工具类
 * @author YangJie [2018年12月25日]
 */
public class BeanUtil {
	
	/**
	 * 转换实体
	 * 将obj中属性复制到返回bean中
	 * @param obj
	 * @param clazz
	 * @return
	 * @throws Exception 
	 */
	public static <T> T transformBean(Object obj, Class<T> clazz) throws Exception{
		if(Objects.nonNull(obj)) {
			T t = clazz.newInstance();
			BeanUtils.copyProperties(obj, t);
			return t;
		}
		return null;
	}
	
	/**
	 * 转换List中实体
	 * 将obj中属性复制到返回bean中
	 * @param objList
	 * @param clazz
	 * @return
	 * @throws Exception 
	 */
	public static <T> List<T> transformList(Object objList, Class<T> clazz) throws Exception{
		List<T> tList = new ArrayList<T>();
		if (objList != null && objList instanceof List<?>) {
			for(Object obj : (List<?>)objList){
				tList.add(transformBean(obj, clazz));
			}
		}
		return tList;
	}
	
	/**
	 * 复制属性
	 * @param source
	 * @param target
	 */
	public static void copyProperties(Object source, Object target) {
		BeanUtils.copyProperties(source, target);
	}
	
}
